@@ -96,8 +96,42 @@ class TestGemCommandsInstallCommand < Gem::TestCase
     assert_match "1 gem installed", @ui.output
   end
 
+  def test_execute_local_transitive_prerelease
+    specs = spec_fetcher do |fetcher|
+      fetcher.download 'a', 2, 'b' => "2.a", 'c' => '3'
+      fetcher.download 'b', '2.a'
+      fetcher.download 'c', '3'
+    end
+
+    @cmd.options[:domain] = :local
+
+    FileUtils.mv specs['a-2'].cache_file, @tempdir
+    FileUtils.mv specs['b-2.a'].cache_file, @tempdir
+    FileUtils.mv specs['c-3'].cache_file, @tempdir
+
+    @cmd.options[:args] = %w[a]
+
+    use_ui @ui do
+      orig_dir = Dir.pwd
+      begin
+        Dir.chdir @tempdir
+        FileUtils.rm_r [@gemhome, "gems"]
+        assert_raises Gem::MockGemUi::SystemExitException, @ui.error do
+          @cmd.execute
+        end
+      ensure
+        Dir.chdir orig_dir
+      end
+    end
+
+    assert_equal %w[a-2 b-2.a c-3], @cmd.installed_specs.map { |spec| spec.full_name }.sort
+
+    assert_match "3 gems installed", @ui.output
+  end
+
   def test_execute_no_user_install
     skip 'skipped on MS Windows (chmod has no effect)' if win_platform?
+    skip 'skipped in root privilege' if Process.uid.zero?
 
     specs = spec_fetcher do |fetcher|
       fetcher.gem 'a', 2
@@ -382,6 +416,43 @@ ERROR:  Possible alternatives: non_existent_with_hint
     assert_path_exists File.join(a2.doc_dir, 'rdoc')
   end
 
+  def test_execute_rdoc_with_path
+    skip if RUBY_VERSION <= "1.8.7"
+    specs = spec_fetcher do |fetcher|
+      fetcher.gem 'a', 2
+    end
+  
+    Gem.done_installing(&Gem::RDoc.method(:generation_hook))
+  
+    @cmd.options[:document] = %w[rdoc ri]
+    @cmd.options[:domain] = :local
+    @cmd.options[:install_dir] = 'whatever'
+  
+    a2 = specs['a-2']
+    FileUtils.mv a2.cache_file, @tempdir
+  
+    @cmd.options[:args] = %w[a]
+  
+    use_ui @ui do
+      # Don't use Dir.chdir with a block, it warnings a lot because
+      # of a downstream Dir.chdir with a block
+      old = Dir.getwd
+  
+      begin
+        Dir.chdir @tempdir
+        assert_raises Gem::MockGemUi::SystemExitException, @ui.error do
+          @cmd.execute
+        end
+      ensure
+        Dir.chdir old
+      end
+    end
+  
+    wait_for_child_process_to_exit
+  
+    assert_path_exists 'whatever/doc/a-2', 'documentation not installed'
+  end
+
   def test_execute_saves_build_args
     specs = spec_fetcher do |fetcher|
       fetcher.gem 'a', 2
@@ -588,7 +659,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
       done_installing = true
     end
 
-    spec = quick_spec 'a', 2
+    spec = util_spec 'a', 2
 
     util_build_gem spec
 
@@ -616,7 +687,7 @@ ERROR:  Possible alternatives: non_existent_with_hint
   end
 
   def test_install_gem_ignore_dependencies_specific_file
-    spec = quick_spec 'a', 2
+    spec = util_spec 'a', 2
 
     util_build_gem spec
 
